@@ -30,15 +30,15 @@ def deploy(directory):
     """
     Deploys a directory to given cloud provider.
     """
-    if not glob.glob("*.glide.json"):
+    if not glob.glob("*.glide.json") and not glob.glob(directory + "/*.glide.json"):
         click.echo('\033[91m' + "ERROR: Glide file not found. Please run init command." + '\033[0m')
         sys.exit(1) 
 
-    for file in glob.glob("*.glide.json"):
+    for file in glob.glob("*/*.glide.json"):
         with open(file, 'r') as f:
             glideJson = json.loads(f.read())
 
-            if glideJson['project_name'] != f.name.replace('.glide.json', ''):
+            if glideJson['project_name'] != f.name[len(directory)+1:].replace('.glide.json', ''):
                 err("ERROR: Project name does not match glide file name.")
                 sys.exit(1)
 
@@ -61,7 +61,7 @@ def migrate(cloud):
     """
     Migrates current configuration to the given cloud provider.
     """
-    if not glob.glob("*.glide.json"):
+    if not glob.glob("*.glide.json") and not glob.glob(directory + "/*.glide.json"):
         err("ERROR: Glide file not found. Please run init command.")
 
     for file in glob.glob("*.glide.json"):
@@ -98,10 +98,10 @@ def sites():
     """
     Shows all available user sites.
     """
-    if not glob.glob("*.glide.json"):
+    if not glob.glob("*.glide.json") and not glob.glob("*/*.glide.json"):
         err("ERROR: Glide file not found. Please run init command.")
 
-    for file in glob.glob("*.glide.json"):
+    for file in glob.glob("*/*.glide.json"):
         with open(file, 'rb') as f:
             glideJson = json.loads(f.read())
 
@@ -126,5 +126,6 @@ cli.add_command(init)
 cli.add_command(deploy)
 cli.add_command(migrate)
 cli.add_command(sites)
-cli.add_command(dev)
 
+if __name__ == '__main__':
+    cli()
\ No newline at end of file
