@@ -4,7 +4,7 @@ class Deployment:
     def __init__(self, deploymentName, directoryToDeploy):
         self.deploymentName = deploymentName
         self.directoryToDeploy = directoryToDeploy
-        self.api = Api(self.deploymentName)
+        self.api = Api(self.deploymentName, directoryToDeploy)
     
     def deployToNetlify(self):
         self.api.deployToNetlify(self.directoryToDeploy)
